#
# spec file for package python-PeachPy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%bcond_without python2
Name:           python-PeachPy
Version:        0.2.0~pre.20221113T090827.349e8f8
Release:        2.0.2.1.sr20240803
Summary:        Portable Efficient Assembly Codegen in Higher-level Python
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/Maratyszcza/PeachPy
Source0:        PeachPy-%{version}.tar.xz
BuildRequires:  %{python_module opcodes >= 0.3.13}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six
ExclusiveArch:  x86_64
%ifpython2
Requires:       python-enum34
%endif
%if %{with python2}
BuildRequires:  python-enum34
%endif
%python_subpackages

%description
Portable Efficient Assembly Code-generator in Higher-level Python (PEACH-Py)
PEACH-Py is a Python framework for writing high-performance assembly kernels.
PEACH-Py is developed to simplify writing optimized assembly kernels while
preserving all optimization opportunities of traditional assembly. Some
PEACH-Py features:
  - Automatic register allocation
  - Stack frame management, including re-aligning of stack frame as needed
  - Generating versions of a function for different calling conventions from
    the same source (e.g. functions for Microsoft x64 ABI and System V x86-64
    ABI can be generated from the same source)
  - Allows to define constants in the place where they are used (just like in
    high-level languages)
  - Tracking of instruction extensions used in the function.
  - Multiplexing of multiple instruction streams (helpful for software
    pipelining)

%prep
%setup -q -n PeachPy-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# https://github.com/Maratyszcza/PeachPy/issues/131
%pytest -k 'not TestARM'

%files %{python_files}
%doc README.rst
%license LICENSE.rst
%{python_sitelib}/*

%changelog
* Wed Aug 28 2024 Guang Yee <gyee@suse.com>
- Enable sle15_python_module_pythons.
* Mon Mar 27 2023 hpj@urpla.net
- Update to version 0.2.0~pre.20221113T090827.349e8f8:
  * Import setuptools before distutils
  * AppVeyor: Python 2.7, 3.6, 3.8, 3.10 (#130)
  * Fix typos discovered by codespell
  * Use print() function in both Python 2 and Python 3
  * Make the build reproducible
  * Update setup.py
  * Adds RDSEED starting from Broadwell
  * Fix rip register usage in AT&T assembly (#112)
  * Support simple syntax for RIP-relative CALL (#107)
  * Allow asm printing for CALL(RIPRelativeOffset(3)) (#105)
- pytest is used for testing now, remove rednose dependency
- Disable dysfunctional arm tests
- Changed service to spell out timestamp in human readable form
  and to create a changelog entry on updates
- Removed outdated automated-convertion-form-2to3.patch
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
- Fix the version to match reality as it is git repo snapshot
* Wed Dec 11 2019 Christian Goll <cgoll@suse.com>
- removed i586 builds as the instructions are x86_64 specific
* Tue Nov  5 2019 Christian Goll <cgoll@suse.com>
- updated to actual master from github, as setup.py was fixed upstream
  * removed removed-enum-for-new-pythons.patch
* Wed Sep  4 2019 Christian Goll <cgoll@suse.com>
- initial release of PeachPy
  * added removed-enum-for-new-pythons.patch to fix wrong
    requirement for enum in setup.py
  * added automated-convertion-form-2to3.patch, to cover the nosetets
    also for python3
